@@ -1081,6 +1081,7 @@ int    AFS::try_to_cache(FILE * fp, char *name, int mode)
 
 static void parse_month(struct tm &tm, char *w)
 {
+  int i;
   static char *mon[] = { "jan", "feb", "mar", "apr", "may", "jun",
                          "jul", "aug", "sep", "oct", "nov", "dec" };
   char buf[4];
@@ -1090,10 +1091,10 @@ static void parse_month(struct tm &tm, char *w)
     tm.tm_mon--;
     return;
   }
-  for (int i=0; i < 3; i++)
+  for (i=0; i < 3; i++)
     buf[i] = tolower(w[i]);
   buf[3] = 0;
-  for (int i=0; i < 12; i++) {
+  for (i=0; i < 12; i++) {
     if (strcmp(mon[i], buf) == 0) {
       tm.tm_mon = i;
       return;
