@@ -4,6 +4,9 @@
 #include <config.h>
 #endif
 #include <globdef.h>
+#ifdef HAVE_SYS_SIGEVENT_H
+#include <sys/sigevent.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -11,6 +14,7 @@
 #include <fcntl.h>
 #include <sys/param.h>
 #include <sys/types.h>
+#include "types.h"
 /*
 const int EQ=-1;
 const int LESS=-2;
