@@ -50,4 +50,14 @@ char internal_keysbuf[]=
 "ChangeOwner: Shift+F9;\n"
 "CleanAFScache: Ctrl+c;\n"
 "ActivateFtpLink: Ctrl+h;\n"
+"InsertLeftDir: Ctrl+bracketleft;\n"
+"InsertRightDir: Ctrl+bracketright;\n"
+"SelectFileMask: Shift+KP_Add;\n"
+"DeselectFileMask: Shift+KP_Subtract;\n"
+"MoveCursorHome: Home;\n"
+"MoveCursorEnd: End;\n"
+"MoveCursorPageDown: Next;\n"
+"MoveCursorPageUp: Prior;\n"
+"InodeInfo: Ctrl+i;\n"
+"QuickFileInfo: KP_Insert;KP_0;\n"
 ">endLSF";
