@@ -9,6 +9,8 @@ extern void init_ftp_globals();
 extern void ftp_backgrounds(fd_set*);
 extern int   ftp_backgrounds_fdset(fd_set*, int);
 extern void ftp_set_bgcode(FTP*,int);
+extern int where_is_ftp_place(FTP *o);
+extern int is_this_ftp(FTP* o);
 
 /* Here we define FtpFunctions which can be send to background */
 #define FF_NON        0        //NON BLOCKED OPERATION
@@ -21,7 +23,14 @@ extern void ftp_set_bgcode(FTP*,int);
 #define FF_SVI        7        //SIMPLE VIEW
 #define FF_EDI       8       //EDIT FILE
 #define FF_MGET   9       //MultiGet FILES
+#define FF_DEL     10     //DELETE file
+#define FF_MDEL  11    //MultiDEL files
+#define FF_MKD    12    //Make directory
+#define FF_DIE      13   //Unplanning child die :(
+#define FF_PUT      14   //Put file to FTP
+#define FF_MPUT   15  //MultiPut files
 
 #define FGM        0        //FTP in ForeGround Mode
 #define BGM        1        //FTP in BackGround Mode
+
 #endif
