@@ -53,7 +53,7 @@ class FtpVisual: public Gui
   virtual void show_tumb(int i, int ix);
   virtual void show_empty_tumb(int i, int ix);
   void refresh(FTP* fo);
-  void rescan();
+  virtual void rescan();
   void animate_moving(int);
 };
 
