@@ -168,9 +168,11 @@ void   SpecialWin::init(Window ipar)
   XSetForeground(disp, pgc, 1);
   XFillArc(disp, pm1, pgc, l / 2 - tw / 2, 0, tw, tw, 0, 360 * 64);
   XFillRectangle(disp, pm1, pgc, 0, tw - 5, l, 25);
+#ifdef HAVE_X11_EXTENSIONS_SHAPE_H
   if (XShapeQueryExtension(disp, &es1, &es2))
     XShapeCombineMask(disp, w, ShapeBounding, 0, 0, pm1, ShapeSet);
   else
+#endif
     fprintf(stderr, "XShape extensions not supported.\n");
   XFreeGC(disp, pgc);
   prflg = 0;
@@ -1681,7 +1683,7 @@ void   MenuBar::showitem(int i)
   {
           XCopyArea(disp, skin[i].im->skin, w, gcw, skin[i].x, skin[i].y,
                   (unsigned)skin[i].l, (unsigned)skin[i].h, dx[i], 0);
-          if(last_idx==i)
+          if(last_idx==i && pskin)
           {
               if(skin[i].tox<0)
                   XCopyArea(disp, pskin->im->skin, w, gcw, pskin->x, pskin->y,
@@ -1734,12 +1736,14 @@ void   MenuBar::pressitem(int i)
       items[i].o->init(parent);
       if(kx+items[i].o->l > l+x-deltal)
       {
+	if(pskin)
          XCopyArea(disp, pskin->im->skin, w, gcw, pskin->x, pskin->y,
            (unsigned)pskin->l, (unsigned)pskin->h, dx[i]+dl[i]-2-pskin->l, menuh-pskin->h+1);
          kx=l+x-items[i].o->l - 4;
          items[i].o->right_justified=YES;
       } else
       {
+	if(pskin)
          XCopyArea(disp, pskin->im->skin, w, gcw, pskin->x, pskin->y,
                  (unsigned)pskin->l, (unsigned)pskin->h, dx[i]+2, menuh-pskin->h+1);
          items[i].o->right_justified=NO;
