@@ -611,8 +611,9 @@ XImage *LoadXImage(char *file,int cmptype,int type)
     case F_JPEG:
 #ifdef JPEGSUPPORT
         im_clear_pic();
-         translation=1;
-         if(LoadJFIF(file,&im)) break;else {fprintf(stderr,"Image Engine: LoadJpeg\n");return NULL;};
+        if(vclass==PseudoColor) translation=0;
+        else translation= 1;
+        if(LoadJFIF(file,&im)) break;else {fprintf(stderr,"Image Engine: LoadJpeg\n");return NULL;};
 #else
          return NULL;
 #endif
