@@ -15,7 +15,10 @@ class IVES_client
   Atom xa_ives_retval;
   Window w;
   void (*func)(int);
+  int (*prev_handler)(Display*, XErrorEvent*);
   Atom gen_ives_id();
+  void ignore_xerror();
+  void restore_xerror();
  public:
   IVES_client(void (*ifunc)(int)=0) { func=ifunc;};
   int Init();
