@@ -19,7 +19,7 @@
 #include <signal.h>
 #include <time.h>
 
-#ifdef __FreeBSD__
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
 #endif
 
@@ -29,7 +29,9 @@
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
 #include <X11/Xresource.h>
+#ifdef HAVE_X11_EXTENSIONS_SHAPE_H
 #include <X11/extensions/shape.h>
+#endif
 #include <X11/keysym.h>
 
 #define BDWIDTH   1
