@@ -16,6 +16,7 @@
 #include "scroll.h"
 #include "skin.h"
 #include "geomfuncs.h"
+#include "baseguiplugin.h"
 const Time DBLCLICK = 250;
 
 ///////////////////////////Panel class/////////////////////////////////////
@@ -55,7 +56,7 @@ void   Panel::init(Window ipar)
   XSelectInput(disp, w, ButtonReleaseMask |
            ButtonPressMask | ExposureMask | KeyPressMask | FocusChangeMask);
   base = cur = 0;
-  scr = new ScrollBar(-1, 0, h - 2, this);
+  scr = baseguiplugin->new_ScrollBar(-1, 0, h - 2, this);
   scr->setrange(0, 1);
   scr->init(w);
 }
