@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: panel.cxx,v 1.9 2000/12/13 13:27:41 leo Exp $ */
+/* $Id: panel.cxx,v 1.1.1.1 2001/04/17 08:45:25 leo Exp $ */
 #include "panel.h"
 #include "au/key.h"
 #include "au/x_actions.h"
@@ -27,6 +27,7 @@
 #include "ftpcfg.h"
 #include "c_externs.h"
 #include "internals.h"
+#include "baseguiplugin.h"
 
 const Time DBLCLICK = 250;
 
@@ -140,7 +141,7 @@ void   Lister::init(Window ipar)
 
   init_dnd();
 
-  scr=new ScrollBar(l-24,28,h-28-35,this);
+  scr=baseguiplugin->new_ScrollBar(l-24,28,h-28-35,this);
   scr->setrange(0,10);
   scr->init(w);
 
