@@ -5,8 +5,8 @@
 class QuickHelp: public Gui
 {
  public:
-  int x,y,prflg,tx,ty,nl,ty2;
-  uint l,h,tl;
+  int prflg,tx,ty,nl,ty2;
+  uint tl;
   ulong col;
   int mapped,shown;
   char name[256];
