@@ -12,7 +12,7 @@
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
  ****************************************************************************/
-/* $Id: qview.cxx,v 1.4 2000/12/22 06:12:28 leo Exp $ */
+/* $Id: qview.cxx,v 1.2 2001/04/17 11:29:45 leo Exp $ */
 #include "panel.h"
 #include "exwin.h"
 #include "internals.h"
@@ -185,7 +185,7 @@ void   qredraw(Window win, GC & gcw)
   XDrawString(disp, win, gcw, 18, 42, "Subdirs:", 8);
   XDrawString(disp, win, gcw, 18, 64, "Files:", 6);
   XDrawString(disp, win, gcw, 10, 89, "Total Size:", 11);
-  XSetForeground(disp, gcw, cols[1]);
+  XSetForeground(disp, gcw, guiplugin->get_exwin_foreground());
   XDrawString(disp, win, gcw, 110, 20, qvname, strlen(qvname));
   XDrawString(disp, win, gcw, 110, 42, tmp1, strlen(tmp1));
   XDrawString(disp, win, gcw, 110, 64, tmp2, strlen(tmp2));
