@@ -46,6 +46,7 @@
 #endif
 
 #include <X11/keysym.h>
+
 #ifndef NO_XLOCALE
 # if (XtSpecificationRelease < 6)
 #  define NO_XLOCALE
@@ -66,8 +67,21 @@
 #ifdef HAVE_SYS_IOCTL_H
 # include <sys/ioctl.h>
 #endif
+
+#ifdef HAVE_SYS_SELECT_H
+#include <sys/select.h>
+#endif
+
+#ifdef HAVE_UNIX_H
+#include <unix.h>
+#endif
+
 #include <sys/types.h>
+
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
+
 #include <stdarg.h>
 
 /* #define USE_GETGRNAME */
@@ -80,13 +94,15 @@ extern int main_show;
 int vt_show=1;
 int focus_fl=0;
 extern Window Main;
-extern int (*xnc_event)(XEvent*);
-extern void (*xnc_setsignals)();
-extern int (*xnc_look_for_key)(XEvent*);
-extern void (*xnc_setdir)();
-extern void  (*xnc_work_anim)();
-extern void  (*xnc_look_at_pipes)(fd_set*);
+extern int    (*xnc_event)(XEvent*);
+extern void   (*xnc_setsignals)();
+extern int    (*xnc_look_for_key)(XEvent*);
+extern void   (*xnc_setdir)();
+extern void   (*xnc_work_anim)();
+extern void   (*xnc_look_at_pipes)(fd_set*);
 extern int    (*xnc_set_pipes)(fd_set*, int);
+extern int    (*xnc_is_my_child)(int,int);
+extern void   (*xnc_run_once)();
 int onlyrun=1;
 int disable_modifiers=0;
 extern Window main_win;
@@ -448,18 +464,23 @@ privileges (int mode)
 static RETSIGTYPE
 Child_signal (int unused)
 {
-   int pid, save_errno = errno;
-
+   int pid, save_errno = errno, status;
+/*
    do
      {
         errno = 0;
      }
    while ((-1 == (pid = waitpid (cmd_pid, NULL, WNOHANG))) &&
           (errno == EINTR));
+*/
+   pid=wait(&status);
+   if(pid!=-1)
+   {
+     if (pid == cmd_pid) exit (EXIT_SUCCESS);
+     errno = save_errno;
 
-   if (pid == cmd_pid) exit (EXIT_SUCCESS);
-   errno = save_errno;
-
+     xnc_is_my_child(pid,status);
+   }
    signal (SIGCHLD, Child_signal);
 }
 
@@ -559,7 +580,7 @@ Exit_signal (int sig)
 /*
  * Exit gracefully, clearing the utmp entry and restoring tty attributes
  */
-void (*xnc_kill)();
+extern void (*xnc_kill)();
 void
 clean_exit (void)
 {
@@ -1043,6 +1064,41 @@ get_ttymode (ttymode_t * tio)
 }
 /*}}}*/
 
+int is_show_intro()
+{
+        return Options & Opt_showIntro;
+}
+
+int is_term_on()
+{
+        return (Options & Opt_termOff) ? 0 : 1;
+}
+
+int is_look_five()
+{
+        return (Options & Opt_lookFive) ? 1 : 0;
+}
+
+int is_fast_load()
+{
+        return Options & Opt_fastLoad;
+}
+
+void reset_fast_loading()
+{
+        Options&= ~Opt_fastLoad;
+}
+
+int is_back_load()
+{
+  return (Options & Opt_backLoad) ? 1 : 0;
+}
+
+void unset_back_load()
+{
+  Options&= ~Opt_backLoad;
+}
+
 /*{{{ run_command() */
 /*
  * Run the command in a subprocess and return a file descriptor for the
@@ -1449,6 +1505,8 @@ lookup_key (XEvent * ev)
      }
   if(xnc_look_for_key(ev)==ASwitchtoTerm)
    {
+     if(!is_term_on())
+             return;
      focus_fl^=1;
      if(focus_fl) {
        if(main_show)
@@ -1903,18 +1961,24 @@ cmd_getc (void)
                goto Return_Char;
           }
         /* Nothing to do! */
+	if(xnc_run_once)
+	  {
+	     xnc_run_once();
+	     xnc_run_once=0;
+	  }
         FD_ZERO (&readfds);
         FD_SET (cmd_fd, &readfds);
         FD_SET (Xfd, &readfds);
         value.it_value.tv_usec = TIMEOUT_USEC;
         value.it_value.tv_sec = 0;
-        
-        maxfd=xnc_set_pipes(&readfds, num_fds-1)+1;
-        
+
+        maxfd=Xfd > cmd_fd ? Xfd : cmd_fd;
+
+        maxfd=xnc_set_pipes(&readfds, maxfd)+1;
         retval = select (maxfd, &readfds, NULL, NULL,
                                 (refreshed ? NULL : &value.it_value));
-
-        xnc_look_at_pipes(&readfds);
+        if(retval>0)
+                xnc_look_at_pipes(&readfds);
 
         /* See if we can read from the application */
         if (FD_ISSET (cmd_fd, &readfds))
@@ -1979,7 +2043,6 @@ process_x_event (XEvent * ev)
 #define clickOnce()        (clicks <= 1)
    static int bypass_keystate = 0;
    int reportmode;
-
   if(xnc_event(ev)) return;
    switch (ev->type) {
     case KeyPress:
@@ -1987,7 +2050,6 @@ process_x_event (XEvent * ev)
       break;
 
     case ClientMessage:
-/*    fprintf(stderr,"Dnd recieve: %X\n",ev->xclient.data.l[0]);*/
       if (ev->xclient.format == 32 && ev->xclient.data.l[0] == wmDeleteWindow)
         exit (EXIT_SUCCESS);
 #ifdef OFFIX_DND
@@ -2381,9 +2443,18 @@ process_x_event (XEvent * ev)
 /*
  * Send count characters directly to the command
  */
+
+int bool_term_on=1; 
+
+#define  MAX_OUT 2048
+char off_buf[MAX_OUT];
+int off_count=0;
+
 void
 tt_write (const unsigned char * buf, unsigned int count)
 {
+  if(bool_term_on)
+  {
    while (count > 0)
      {
         int n = write (cmd_fd, buf, count);
@@ -2393,6 +2464,29 @@ tt_write (const unsigned char * buf, unsigned int count)
              buf += n;
           }
      }
+  } else
+  {
+     int i=0;
+     while(i<count && off_count<MAX_OUT && buf[i]!=0)
+     {
+       if(buf[i]==8)
+       {
+          if(off_count>0)
+                  off_count--;
+          i++;
+       } else
+       if(buf[i]!='\n' && buf[i]!='\r')
+               off_buf[off_count++]=buf[i++];
+       else
+       {
+               i++;
+               off_buf[off_count]=0;
+               if(off_count)
+                       psystem(off_buf);
+               off_count=0;
+       }
+     }
+  }
 }
 
 /*
