@@ -11,8 +11,8 @@ class BKey: public Gui
 {
   Gui *o;
  public:
-  int x,y,prflg,hflg,ff;
-  uint l,h,pl,ph;
+  int prflg,hflg,ff;
+  uint pl,ph;
   Pixmap pix;
   BKey(int ix,int iy,int il,int ih,Gui*,int);
   ~BKey() {if(disp) XFreeGC(disp,gcw);hflg=0;};
@@ -27,14 +27,13 @@ class ScrollBar: public Gui
 {
   Gui *o;
  public:
-  int x,y,prflg,hflg,val,minval,maxval,range;
+  int prflg,hflg,val,minval,maxval,range;
   BKey *upk,*downk;
   void (*scrup)(Gui*);
   void (*scrdown)(Gui*);
   void (*scr)(Gui*);
   void (*scring)(Gui*);
-  uint l,h;
-  int pages,pagesize,bmy;
+  int pages,pagesize,bmy,shown;
   ScrollBar(int ix,int iy,int ih,Gui*);
   ~ScrollBar() {if(disp) XFreeGC(disp,gcw);hflg=0;delete upk;delete downk;};
   virtual void init(Window ipar);
