@@ -708,9 +708,11 @@ void   InitXClient(int argc, char **argv, int wx, int wy, int wl, int wh, char
   struct utsname uts;
   int    i, ppx, ppy;
   XWindowAttributes xwinattr;
+  XrmDatabase plugin_rdb;
   uint   ppl, pph;
   char  *rmt;
   char   tmppath[256];
+  char   plugin_rfile[1024];
   XSetWindowAttributes xswa;
   make_home_file_dir();
   fprintf(stderr, "XClient..........OK [Display '%s']\n", display_name);
@@ -733,8 +735,15 @@ void   InitXClient(int argc, char **argv, int wx, int wy, int wl, int wh, char
   XrmInitialize();
   fprintf(stderr, "Loading resources....");
   strcpy(rfile, home_files_dir);
-  strcat(rfile, guiplugin->get_ini_filename());
+  strcat(rfile, "/xnc.ini");
+  strcpy(plugin_rfile, home_files_dir);
+  strcat(plugin_rfile, guiplugin->get_ini_filename());
+  plugin_rdb = XrmGetFileDatabase(plugin_rfile);
   rdb = XrmGetFileDatabase(rfile);
+
+  if(rdb && plugin_rdb)
+    XrmMergeDatabases(plugin_rdb,&rdb);
+
   if (rdb != NULL)
     for (i = 0; i < resn; i++)
       {
