@@ -101,7 +101,7 @@ void check_source_dirs()
   {
    fprintf(stderr,"\n****************************************************************\n"
         "Global ERROR: Can't find XNC system configuration files in '%s' or '%s'\n"
-        "Exiting.....\n",rel_dir,xnc_dir);
+        "Exiting.....\n",rel_dir,setup_dir);
    exit(256);
   }
 }
@@ -692,22 +692,22 @@ void set_start_colors()
    int r,g,b,rr,gg,bb;
    for(int i=0;i<14;i++)
      {
-	r=startcol[i][0];
-	g=startcol[i][1];
-	b=startcol[i][2];
-	if(transcol[i]==transcol[0])
-	  {
-	     clipl.pic.pal[3]=r*60/100;
-	     clipl.pic.pal[4]=g*60/100;
-	     clipl.pic.pal[5]=b*60/100;
-	     rr=r*130/100;if(rr>255)  rr=255;
-	     gg=g*130/100;if(gg>255)  gg=255;
-	     bb=b*130/100;if(bb>255)  bb=255;
-	     clipl.pic.pal[24]=rr;
-	     clipl.pic.pal[25]=gg;
-	     clipl.pic.pal[26]=bb;
-	  }
-	clipl.setcol(transcol[i], r, g, b);
+        r=startcol[i][0];
+        g=startcol[i][1];
+        b=startcol[i][2];
+        if(transcol[i]==transcol[0])
+          {
+             clipl.pic.pal[3]=r*60/100;
+             clipl.pic.pal[4]=g*60/100;
+             clipl.pic.pal[5]=b*60/100;
+             rr=r*130/100;if(rr>255)  rr=255;
+             gg=g*130/100;if(gg>255)  gg=255;
+             bb=b*130/100;if(bb>255)  bb=255;
+             clipl.pic.pal[24]=rr;
+             clipl.pic.pal[25]=gg;
+             clipl.pic.pal[26]=bb;
+          }
+        clipl.setcol(transcol[i], r, g, b);
      }
 }
 
